@@ -46,7 +46,7 @@ abstract class AbstractConnection extends AbstractChannel
     );
 
     /**
-     * @var AMQPChannel[]
+     * @var AMQPChannel[]|AbstractChannel[]
      * @internal
      */
     public $channels = array();
@@ -169,8 +169,8 @@ abstract class AbstractConnection extends AbstractChannel
      * @param string $locale
      * @param AbstractIO $io
      * @param int $heartbeat
-     * @param int $connection_timeout
-     * @param float $channel_rpc_timeout
+     * @param int|float $connection_timeout
+     * @param int|float $channel_rpc_timeout
      * @throws \Exception
      */
     public function __construct(
@@ -187,7 +187,7 @@ abstract class AbstractConnection extends AbstractChannel
         $channel_rpc_timeout = 0.0
     ) {
         if (is_null($io)) {
-            throw new \InvalidArgumentException('"io" can not be null');
+            throw new \InvalidArgumentException('Argument $io cannot be null');
         }
 
         // save the params for the use of __clone
@@ -337,11 +337,15 @@ abstract class AbstractConnection extends AbstractChannel
     }
 
     /**
-     * @param int $sec
+     * @param int|null $sec
      * @param int $usec
-     * @return mixed
+     * @return int
+     * @throws AMQPIOException
+     * @throws AMQPRuntimeException
+     * @throws AMQPConnectionClosedException
+     * @throws AMQPRuntimeException
      */
-    public function select($sec, $usec = 0)
+    public function select(?int $sec, int $usec = 0): int
     {
         try {
             return $this->io->select($sec, $usec);
@@ -413,7 +417,7 @@ abstract class AbstractConnection extends AbstractChannel
 
     /**
      * @return int
-     * @throws \PhpAmqpLib\Exception\AMQPRuntimeException
+     * @throws AMQPRuntimeException
      */
     public function get_free_channel_id()
     {
@@ -427,7 +431,7 @@ abstract class AbstractConnection extends AbstractChannel
     }
 
     /**
-     * @param string $channel
+     * @param int $channel
      * @param int $class_id
      * @param int $weight
      * @param int $body_size
@@ -444,7 +448,7 @@ abstract class AbstractConnection extends AbstractChannel
     /**
      * Returns a new AMQPWriter or mutates the provided $pkt
      *
-     * @param string $channel
+     * @param int $channel
      * @param int $class_id
      * @param int $weight
      * @param int $body_size
@@ -510,7 +514,7 @@ abstract class AbstractConnection extends AbstractChannel
     }
 
     /**
-     * @param string $channel
+     * @param int $channel
      * @param array $method_sig
      * @param AMQPWriter|string $args
      * @param null $pkt
@@ -525,7 +529,7 @@ abstract class AbstractConnection extends AbstractChannel
     /**
      * Returns a new AMQPWriter or mutates the provided $pkt
      *
-     * @param string $channel
+     * @param int $channel
      * @param array $method_sig
      * @param AMQPWriter|string $args
      * @param AMQPWriter|null $pkt
@@ -562,7 +566,7 @@ abstract class AbstractConnection extends AbstractChannel
      * @return array
      * @throws \Exception
      * @throws \PhpAmqpLib\Exception\AMQPTimeoutException
-     * @throws \PhpAmqpLib\Exception\AMQPRuntimeException
+     * @throws AMQPRuntimeException
      */
     protected function wait_frame($timeout = 0)
     {
@@ -1025,7 +1029,7 @@ abstract class AbstractConnection extends AbstractChannel
     /**
      * Get the connection blocked state.
      * @return bool
-     * @since v2.12.0
+     * @since 2.12.0
      */
     public function isBlocked()
     {
